import React, { useState } from 'react';
import { X, Server, Cpu, MemoryStick as Memory, Link } from 'lucide-react';
import { storage } from '../utils/storage';
import toast from 'react-hot-toast';
import type { CPU } from '../types';

interface AddServerModalProps {
  isOpen: boolean;
  onClose: () => void;
  onServerAdded: () => void;
}

export function AddServerModal({ isOpen, onClose, onServerAdded }: AddServerModalProps) {
  const [formData, setFormData] = useState({
    name: '',
    model: '',
    cpuModel: '',
    cpuCores: 1,
    cpuCount: 1,
    ram_gb: '',
    proxmox_url: ''
  });

  if (!isOpen) return null;

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    
    try {
      // Create array of identical CPUs based on count
      const cpus: CPU[] = Array(formData.cpuCount).fill({
        model: formData.cpuModel,
        cores: formData.cpuCores
      });

      storage.addServer({
        name: formData.name,
        model: formData.model,
        cpus,
        ram_gb: parseInt(formData.ram_gb),
        proxmox_url: formData.proxmox_url
      });

      toast.success('Server added successfully');
      onServerAdded();
      onClose();
    } catch (error) {
      toast.error('Failed to add server');
      console.error('Error:', error);
    }
  };

  return (
    <div className="fixed inset-0 bg-black/70 backdrop-blur-sm flex items-center justify-center p-4 z-50 animate-fadeIn">
      <div className="bg-gray-800/90 backdrop-blur rounded-xl p-6 w-full max-w-md border border-gray-700/50 animate-slideIn">
        <div className="flex justify-between items-center mb-6">
          <h2 className="text-2xl font-semibold text-white flex items-center gap-2">
            <Server className="text-purple-400" size={24} />
            Add New Server
          </h2>
          <button 
            onClick={onClose}
            className="text-gray-400 hover:text-white hover:bg-gray-700/50 p-2 rounded-lg transition-colors"
          >
            <X size={20} />
          </button>
        </div>
        
        <form onSubmit={handleSubmit} className="space-y-5">
          <div>
            <label className="block text-sm font-medium text-gray-300 mb-1.5">
              <div className="flex items-center gap-2 mb-2">
                <Server size={16} className="text-purple-400" />
                Server Name
              </div>
            </label>
            <input
              type="text"
              value={formData.name}
              onChange={(e) => setFormData({ ...formData, name: e.target.value })}
              className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
              required
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-300 mb-1.5">Model</label>
            <input
              type="text"
              value={formData.model}
              onChange={(e) => setFormData({ ...formData, model: e.target.value })}
              className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
              placeholder="e.g. Dell R720"
              required
            />
          </div>
          
          <div className="bg-gray-700/30 p-4 rounded-lg space-y-4">
            <div className="flex items-center gap-2 mb-2">
              <Cpu size={18} className="text-purple-400" />
              <span className="text-gray-300 font-medium">CPU Configuration</span>
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1.5">CPU Model</label>
              <input
                type="text"
                value={formData.cpuModel}
                onChange={(e) => setFormData({ ...formData, cpuModel: e.target.value })}
                className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
                placeholder="e.g. Intel Xeon E5-2680 v2"
                required
              />
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1.5">Cores per CPU</label>
              <input
                type="number"
                min="1"
                value={formData.cpuCores}
                onChange={(e) => setFormData({ ...formData, cpuCores: parseInt(e.target.value) })}
                className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
                required
              />
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1.5">Number of CPUs</label>
              <input
                type="number"
                min="1"
                max="8"
                value={formData.cpuCount}
                onChange={(e) => setFormData({ ...formData, cpuCount: parseInt(e.target.value) })}
                className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
                required
              />
            </div>
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-300 mb-1.5">
              <div className="flex items-center gap-2 mb-2">
                <Memory size={16} className="text-purple-400" />
                RAM (GB)
              </div>
            </label>
            <input
              type="number"
              value={formData.ram_gb}
              onChange={(e) => setFormData({ ...formData, ram_gb: e.target.value })}
              className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
              required
            />
          </div>

          <div>
            <label className="block text-sm font-medium text-gray-300 mb-1.5">
              <div className="flex items-center gap-2 mb-2">
                <Link size={16} className="text-purple-400" />
                Proxmox UI URL
              </div>
            </label>
            <input
              type="url"
              value={formData.proxmox_url}
              onChange={(e) => setFormData({ ...formData, proxmox_url: e.target.value })}
              className="w-full bg-gray-700/50 text-white rounded-lg px-4 py-2.5 focus:ring-2 focus:ring-purple-500 focus:outline-none transition-all duration-200"
              placeholder="https://proxmox.example.com:8006"
              required
            />
          </div>
          
          <button
            type="submit"
            className="w-full bg-purple-600 hover:bg-purple-700 text-white font-medium py-3 px-4 rounded-lg transform hover:scale-102 transition-all duration-200 mt-6 animate-pulse hover:animate-none"
          >
            Add Server
          </button>
        </form>
      </div>
    </div>
  );
}